@@ -43,8 +43,14 @@ def member_type_function(g):
         return ""
     head = re.sub(r'<.*?>', '', g.group(1)).strip()
     tail = ''
+
+    spectag = re.search(r'^(.*?)(\[(?:static|virtual)\])(.*)$', head)
+    if spectag:
+        head = spectag.group(1).strip() + ' ' + spectag.group(3).strip()
+        tail = ' ' + spectag.group(2)
+
     cppvertag = re.search(
-        '^(.*?)(\[(?:(?:since|until) )?C\+\+\d+\]\s*(,\s*)?)+$', head)
+        r'^(.*?)(\[(?:(?:since|until) )?C\+\+\d+\]\s*(,\s*)?)+$', head)
     if cppvertag:
         head = cppvertag.group(1).strip()
         tail = ' ' + cppvertag.group(2)
@@ -53,9 +59,8 @@ def member_type_function(g):
         head = ', '.join([x.strip() + ' (3)' for x in head.split(',')])
     else:
         head = head.strip() + ' (3)'
+
     full = (head + tail).replace('"', '\\(dq')
-    """ remove [static] tag as in string::npos[static] """
-    full = full.replace("[static]", "");
     return '\n.IP "%s"\n%s\n' % (full, g.group(2))
 
 
@@ -112,7 +117,7 @@ rps = [
     # Group t-lines
     (r'<span></span>', r'', re.S),
     (r'<span class="t-lines">(?:<span>.+?</span>.*)+</span>',
-     lambda x: re.sub('\s*</span><span>\s*', r', ', x.group(0)), re.S),
+     lambda x: re.sub(r'\s*</span><span>\s*', r', ', x.group(0)), re.S),
     # Member type & function second col is group see basic_fstream for example
     (r'<tr class="t-dsc">\s*?<td>((?:(?!</td>).)*?)</td>\s*?'
      r'<td>((?:(?!</td>).)*?)<table[^>]*>((?:(?!</table>).)*?)</table>'
